@@ -28,7 +28,8 @@ class InflectionalGroup:
             "INF2", "INF3", "BSTAG", "ESTAG", "BTTAG",
             "ETTAG", "BDTAG", "EDTAG", "INF1", "ASLONGAS",
             "DIST", "ADAMANTLY", "PERCENT", "WITHOUTBEINGABLETOHAVEDONESO", "DIM",
-            "PERS", "FRACTION", "HASHTAG", "EMAIL", "DATE"]
+            "PERS", "FRACTION", "HASHTAG", "EMAIL", "DATE",
+            "CODE", "METRIC"]
     morphotags = [MorphologicalTag.NOUN, MorphologicalTag.ADVERB, MorphologicalTag.ADJECTIVE,
                   MorphologicalTag.VERB, MorphologicalTag.A1SG, MorphologicalTag.A2SG, MorphologicalTag.A3SG,
                   MorphologicalTag.A1PL,
@@ -79,7 +80,7 @@ class InflectionalGroup:
                   MorphologicalTag.DISTRIBUTIVE, MorphologicalTag.ADAMANTLY, MorphologicalTag.PERCENT,
                   MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO, MorphologicalTag.DIMENSION,
                   MorphologicalTag.PERSONALPRONOUN, MorphologicalTag.FRACTION, MorphologicalTag.HASHTAG,
-                  MorphologicalTag.EMAIL, MorphologicalTag.DATE]
+                  MorphologicalTag.EMAIL, MorphologicalTag.DATE, MorphologicalTag.CODE, MorphologicalTag.METRIC]
 
     def __init__(self, IG: str):
         """
